@@ -59,19 +59,45 @@ class TestURL(unittest.TestCase):
             'http://example.com/asdf/ghjk',
             URLInfo.parse('example.com/asdf/ghjk#blah').url
         )
+
+        url_info = URLInfo.parse(
+            'HTTP://username:password@example.com/asdf/ghjk/')
         self.assertEqual(
             'http://example.com/asdf/ghjk/',
-            URLInfo.parse(
-                'HTTP://username:password@example.com/asdf/ghjk/').url
+            url_info.url
         )
+        self.assertEqual(
+            'http',
+            url_info.scheme
+        )
+        self.assertEqual(
+            'username',
+            url_info.username
+        )
+        self.assertEqual(
+            'password',
+            url_info.password
+        )
+        self.assertEqual(
+            'utf-8',
+            url_info.encoding
+        )
+
         self.assertEqual(
             'http://example.com/%C3%B0',
             URLInfo.parse('http://example.com/ð').url
         )
+
+        url_info = URLInfo.parse('mailto:user@example.com')
         self.assertEqual(
             'mailto:user@example.com',
-            URLInfo.parse('mailto:user@example.com').url
+            url_info.url
         )
+        self.assertEqual(
+            'mailto',
+            url_info.scheme
+        )
+
         self.assertEqual(
             'http://example.com/',
             URLInfo.parse('http://example.com:80').url
@@ -93,6 +119,10 @@ class TestURL(unittest.TestCase):
             'http://www.xn--hda.com/asdf',
             URLInfo.parse('www.ð.com/asdf').url
         )
+        self.assertEqual(
+            'www.xn--hda.com',
+            URLInfo.parse('www.ð.com/asdf').hostname
+        )
         self.assertEqual(
             'http://example.com/?blah=%C3%B0',
             URLInfo.parse('example.com?blah=ð').url
@@ -102,6 +132,48 @@ class TestURL(unittest.TestCase):
             URLInfo.parse('example.com?blah=%c3%b0').url
         )
 
+        url_info = URLInfo.parse('example.com/文字化け/?blah=文字化け',
+            encoding='shift_jis')
+        self.assertEqual(
+            'http://example.com/%95%B6%8E%9A%89%BB%82%AF/'
+                '?blah=%95%B6%8E%9A%89%BB%82%AF',
+            url_info.url
+        )
+        self.assertEqual(
+            '/%95%B6%8E%9A%89%BB%82%AF/',
+            url_info.path
+        )
+        self.assertEqual(
+            'blah=%95%B6%8E%9A%89%BB%82%AF',
+            url_info.query
+        )
+        self.assertEqual(
+            'shift_jis',
+            url_info.encoding
+        )
+
+        self.assertEqual(
+            'http://example.com/%95%B6%8E%9A%89%BB%82%AF/'
+                '?blah=%95%B6%8E%9A%89%BB%82%AF',
+            URLInfo.parse('example.com/%95%B6%8E%9A%89%BB%82%AF/'
+                '?blah=%95%B6%8E%9A%89%BB%82%AF', encoding='shift_jis').url
+        )
+
+        self.assertEqual(
+            'http://example.com/'
+                '?blah=http%3A%2F%2Fexample.com%2F%3Ffail%3Dtrue',
+            URLInfo.parse(
+                'http://example.com/'
+                    '?blah=http%3A%2F%2Fexample.com%2F%3Ffail%3Dtrue').url
+        )
+        self.assertEqual(
+            'http://example.com/'
+                '?blah=http%3A%2F%2Fexample.com%2F%3Ffail%3Dtrue',
+            URLInfo.parse(
+                'http://example.com/'
+                    '?blah=http://example.com/?fail%3Dtrue').url
+        )
+
     def test_url_info_to_dict(self):
         url_info = URLInfo.parse('https://example.com/file.jpg')
         url_info_dict = url_info.to_dict()
